package net.knarcraft.clearonworldguard;

import net.knarcraft.clearonworldguard.config.Configuration;
import net.knarcraft.clearonworldguard.listener.BlockListener;
import net.knarcraft.clearonworldguard.listener.ClearRegionListener;
import net.knarcraft.clearonworldguard.listener.EntityListener;
import net.knarcraft.clearonworldguard.listener.PlayerListener;
import org.bukkit.Bukkit;
import org.bukkit.configuration.file.FileConfiguration;
import org.bukkit.plugin.java.JavaPlugin;
import org.jetbrains.annotations.NotNull;

import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * The plugin main class
 */
@SuppressWarnings("unused")
public final class ClearOnWorldGuard extends JavaPlugin {

    private static ClearOnWorldGuard instance;
    private boolean debugMode;

    @Override
    public void onEnable() {
        instance = this;
        this.saveDefaultConfig();
        this.reloadConfig();
        FileConfiguration fileConfiguration = this.getConfig();

        // Register the WorldGuard listener
        Configuration configuration = new Configuration(fileConfiguration);
        Bukkit.getPluginManager().registerEvents(new PlayerListener(configuration), this);
        Bukkit.getPluginManager().registerEvents(new EntityListener(configuration), this);
        Bukkit.getPluginManager().registerEvents(new BlockListener(configuration), this);
        Bukkit.getPluginManager().registerEvents(new ClearRegionListener(configuration), this);
        this.debugMode = configuration.debugEnabled();
    }

    /**
     * Gets the logger used by this plugin
     *
     * @return <p>The logger used by this plugin</p>
     */
    public static Logger logger() {
        return instance.getLogger();
    }

    /**
     * Logs a debug message
     *
     * @param message <p>The message to debug</p>
     */
    public static void logDebugMessage(@NotNull String message) {
        if (instance.debugMode) {
            logger().log(Level.INFO, message);
        } else {
            logger().log(Level.FINEST, message);
        }
    }

    /**
     * Gets an instance of this plugin
     *
     * @return <p>An instance of this plugin</p>
     */
    public static ClearOnWorldGuard getInstance() {
        return instance;
    }

}
