package net.knarcraft.clearonworldguard.event;

import com.sk89q.worldguard.protection.regions.ProtectedRegion;
import org.bukkit.entity.Player;
import org.bukkit.event.HandlerList;
import org.bukkit.event.player.PlayerEvent;
import org.jetbrains.annotations.NotNull;

import java.util.Set;

/**
 * An event triggered when a player enters a clear region
 */
public class EnterClearRegionEvent extends PlayerEvent {

    private static final HandlerList HANDLER_LIST = new HandlerList();
    private final Set<ProtectedRegion> regionEntered;

    /**
     * Instantiates a new clear region enter event
     *
     * @param who            <p>The player involved in the event</p>
     * @param regionsEntered <p>The region the player entered</p>
     */
    public EnterClearRegionEvent(@NotNull Player who, @NotNull Set<ProtectedRegion> regionsEntered) {
        super(who);
        this.regionEntered = regionsEntered;
    }

    /**
     * Gets the clear regions the player entered
     *
     * @return <p>The clear regions the player entered</p>
     */
    public Set<ProtectedRegion> getRegionsEntered() {
        return this.regionEntered;
    }

    @NotNull
    @Override
    public HandlerList getHandlers() {
        return HANDLER_LIST;
    }

    /**
     * Gets registers handlers for this event
     *
     * @return <p>Registered handlers for this event</p>
     */
    @SuppressWarnings("unused")
    public static HandlerList getHandlerList() {
        return HANDLER_LIST;
    }

}
