package net.knarcraft.clearonworldguard.event;

import com.sk89q.worldguard.protection.regions.ProtectedRegion;
import org.bukkit.entity.Player;
import org.bukkit.event.HandlerList;
import org.bukkit.event.player.PlayerEvent;
import org.jetbrains.annotations.NotNull;

import java.util.Set;

/**
 * An event triggered when a player leaves a clear region
 */
public class ExitClearRegionEvent extends PlayerEvent {

    private static final HandlerList HANDLER_LIST = new HandlerList();
    private final Set<ProtectedRegion> regionsExited;

    /**
     * Instantiates a new clear region exit event
     *
     * @param who           <p>The player involved in the event</p>
     * @param regionsExited <p>The region the player exited from</p>
     */
    public ExitClearRegionEvent(@NotNull Player who, @NotNull Set<ProtectedRegion> regionsExited) {
        super(who);
        this.regionsExited = regionsExited;
    }

    /**
     * Gets the clear region the player exited from
     *
     * @return <p>The region the player left</p>
     */
    public Set<ProtectedRegion> getRegionsExited() {
        return this.regionsExited;
    }

    @NotNull
    @Override
    public HandlerList getHandlers() {
        return HANDLER_LIST;
    }

    /**
     * Gets registers handlers for this event
     *
     * @return <p>Registered handlers for this event</p>
     */
    @SuppressWarnings("unused")
    public static HandlerList getHandlerList() {
        return HANDLER_LIST;
    }

}
