package net.knarcraft.clearonworldguard.listener;

import com.sk89q.worldguard.protection.regions.ProtectedRegion;
import net.knarcraft.clearonworldguard.ClearOnWorldGuard;
import net.knarcraft.clearonworldguard.config.Configuration;
import net.knarcraft.clearonworldguard.event.EnterClearRegionEvent;
import net.knarcraft.clearonworldguard.event.ExitClearRegionEvent;
import net.knarcraft.clearonworldguard.manager.PlayerRegionTracker;
import org.bukkit.entity.Player;
import org.bukkit.event.EventHandler;
import org.bukkit.event.EventPriority;
import org.jetbrains.annotations.NotNull;

import java.util.Set;

/**
 * A listener for clear region entry and exit
 */
public class ClearRegionListener extends WorldGuardListener {

    /**
     * Instantiates a new WorldGuard listener
     *
     * @param configuration <p>The configuration to get regions and settings from</p>
     */
    public ClearRegionListener(@NotNull Configuration configuration) {
        super(configuration);
    }

    @EventHandler(priority = EventPriority.MONITOR)
    public void onClearRegionEnter(@NotNull EnterClearRegionEvent event) {
        Player player = event.getPlayer();
        Set<ProtectedRegion> regionsEntered = event.getRegionsEntered();
        for (ProtectedRegion region : regionsEntered) {
            PlayerRegionTracker.addRegion(player, region);
        }
    }

    @EventHandler(priority = EventPriority.MONITOR)
    public void onClearRegionExit(@NotNull ExitClearRegionEvent event) {
        Player player = event.getPlayer();
        Set<ProtectedRegion> regionsExited = event.getRegionsExited();
        for (ProtectedRegion region : regionsExited) {
            PlayerRegionTracker.removeRegion(player, region);
        }

        // Clear inventory, since the player left a clear region
        if (!regionsExited.isEmpty()) {
            ClearOnWorldGuard.logDebugMessage("Cleared items and vehicles of player " + player);
            clearInventoriesAndRemoveRecursively(player);
        }
    }

}
