package net.knarcraft.clearonworldguard.manager;

import com.sk89q.worldguard.protection.regions.ProtectedRegion;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

/**
 * A tracker that keeps track of every player's current clear region
 */
public final class PlayerRegionTracker {

    private static final Map<Player, Set<ProtectedRegion>> currentPlayerRegions = new HashMap<>();

    private PlayerRegionTracker() {

    }

    /**
     * Replaces the current clear regions of the given player
     *
     * @param player  <p>The player to add to</p>
     * @param regions <p>The regions to add</p>
     */
    public static void replaceRegions(@NotNull Player player, @NotNull Set<ProtectedRegion> regions) {
        currentPlayerRegions.put(player, new HashSet<>(regions));
    }

    /**
     * Adds the given clear region to the given player
     *
     * @param player <p>The player to add to</p>
     * @param region <p>The region to add</p>
     */
    public static void addRegion(@NotNull Player player, @NotNull ProtectedRegion region) {
        currentPlayerRegions.putIfAbsent(player, new HashSet<>());
        currentPlayerRegions.get(player).add(region);
    }

    /**
     * Removes the given clear region from the given player
     *
     * @param player <p>The player to remove from</p>
     * @param region <p>The region to remove</p>
     */
    public static void removeRegion(@NotNull Player player, @NotNull ProtectedRegion region) {
        currentPlayerRegions.putIfAbsent(player, new HashSet<>());
        currentPlayerRegions.get(player).remove(region);
    }

    /**
     * Checks whether the given player is in any clear region
     *
     * @param player <p>The player to check</p>
     * @return <p>True if the player is in any clear region</p>
     */
    public static boolean isInClearRegion(@NotNull Player player) {
        currentPlayerRegions.putIfAbsent(player, new HashSet<>());
        return !currentPlayerRegions.get(player).isEmpty();
    }

    /**
     * Gets a player's current clear regions
     *
     * @param player <p>The player to get for</p>
     * @return <p>The player's current clear regions</p>
     */
    public static @NotNull Set<ProtectedRegion> getClearRegions(@NotNull Player player) {
        currentPlayerRegions.putIfAbsent(player, new HashSet<>());
        return currentPlayerRegions.get(player);
    }

}
